==> genetic-algorithm-js-1.0.1.tgz: package/lib/Chromosome.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var Chromosome =
/*#__PURE__*/
function () {
  function Chromosome() {
    var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        genes = _ref.genes;

    _classCallCheck(this, Chromosome);

    this.genes = this.mutateGenes(genes || this.createGenes());
    this.fitness = this.calculateFitness();
  }

  _createClass(Chromosome, [{
    key: "getFitness",
    value: function getFitness() {
      return this.fitness;
    }
  }, {
    key: "getGenes",
    value: function getGenes() {
      return this.genes;
    }
  }, {
    key: "mutateGenes",
    value: function mutateGenes(genes) {
      throw new Error('Must supply mutateGenes method');
    }
  }, {
    key: "mate",
    value: function mate(partner) {
      throw new Error('Must supply mate method');
    }
  }, {
    key: "createGenes",
    value: function createGenes() {
      throw new Error('Must supply createGenes method');
    }
  }, {
    key: "calculateFitness",
    value: function calculateFitness() {
      throw new Error('Must supply calculateFitness method');
    }
  }]);

  return Chromosome;
}();

module.exports = Chromosome;

==> genetic-algorithm-js-1.0.4.tgz: package/lib/Chromosome.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var Chromosome =
/*#__PURE__*/
function () {
  function Chromosome() {
    var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {},
        genes = _ref.genes;

    _classCallCheck(this, Chromosome);

    this.setGenes(genes || this.createGenes());
    this.setGenes(this.mutateGenes());
    this.fitness = this.calculateFitness();
  }

  _createClass(Chromosome, [{
    key: "getFitness",
    value: function getFitness() {
      return this.fitness;
    }
  }, {
    key: "getGenes",
    value: function getGenes() {
      return this.genes;
    }
  }, {
    key: "setGenes",
    value: function setGenes(genes) {
      this.genes = genes;
      return this.getGenes();
    } // This method must explicitly call 'setGenes' to return
    // a mutated set of genes

  }, {
    key: "mutateGenes",
    value: function mutateGenes() {
      throw new Error('Must supply mutateGenes method');
    } // This method must return an array of Chromosome instances

  }, {
    key: "mate",
    value: function mate(partner) {
      throw new Error('Must supply mate method');
    } // Must return the data structure of the genes you are keeping

  }, {
    key: "createGenes",
    value: function createGenes() {
      throw new Error('Must supply createGenes method');
    } // Must return the fitness value that was calculated

  }, {
    key: "calculateFitness",
    value: function calculateFitness() {
      throw new Error('Must supply calculateFitness method');
    }
  }]);

  return Chromosome;
}();

module.exports = Chromosome;
